@@ -61,7 +61,7 @@ class TonlibClient:
         """
         if self.tonlib_wrapper is None:            
             self.loaded_contracts_num = 0
-            wrapper = TonLib(self.loop, self.ls_index, self.cdll_path)
+            wrapper = TonLib(self.loop, self.ls_index, self.cdll_path, self.verbosity_level)
             keystore_obj = {
                 '@type': 'keyStoreTypeDirectory',
                 'directory': self.keystore
@@ -85,9 +85,6 @@ class TonlibClient:
             }
             self.tonlib_wrapper = wrapper
 
-            # set verbosity level
-            await self.set_verbosity_level(self.verbosity_level)
-            
             # set confog
             await self.tonlib_wrapper.execute(request)
 
@@ -112,13 +109,6 @@ class TonlibClient:
     def __await__(self):
         return self.init()
 
-    async def set_verbosity_level(self, level):
-        request = {
-            '@type': 'setLogVerbosityLevel',
-            'new_verbosity_level': level
-        }
-        return await self.tonlib_wrapper.execute(request)
-
     # tonlib methods
     async def raw_get_transactions(self, account_address: str, from_transaction_lt: str, from_transaction_hash: str, *args, **kwargs):
         """
@@ -484,7 +474,7 @@ class TonlibClient:
         return result
 
     async def lookup_block(self, workchain, shard, seqno=None, lt=None, unixtime=None, *args, **kwargs):
-        assert seqno or lt or unixtime, "Seqno, LT or unixtime should be defined"
+        assert (seqno is not None) or (lt is not None) or (unixtime is not None), "Seqno, LT or unixtime should be defined"
         mode = 0
         if seqno:
             mode += 1
@@ -507,7 +497,7 @@ class TonlibClient:
         return await self.tonlib_wrapper.execute(request)
 
     async def get_shards(self, master_seqno=None, lt=None, unixtime=None, *args, **kwargs):
-        assert master_seqno or lt or unixtime, "Seqno, LT or unixtime should be defined"
+        assert (master_seqno is not None) or (lt is not None) or (unixtime is not None), "Seqno, LT or unixtime should be defined"
         wc, shard = -1, -9223372036854775808
         fullblock = await self.lookup_block(wc, shard, master_seqno, lt, unixtime)
         request = {
